#
# spec file for package python-googleapis-common-protos
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define modname googleapis-common-protos
%define pkgname %{lua:pname,_ = string.gsub(rpm.expand('%modname'), '-' , '_');print(pname)}
%{?sle15_python_module_pythons}
Name:           python-googleapis-common-protos
Version:        1.63.2
Release:        1.1
Summary:        Common protobufs used in Google APIs
License:        Apache-2.0
Group:          Development/Languages/Python
URL:            https://github.com/googleapis/python-api-common-protos
Source:         https://files.pythonhosted.org/packages/source/g/googleapis-common-protos/googleapis-common-protos-%{version}.tar.gz
Source1:        test_google_api_error_reason.py
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module protobuf >= 3.20.2}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-protobuf >= 3.20.2
Recommends:     python-grpcio >= 1.0.0
BuildArch:      noarch
%if 0%{?sle_version} >= 150400
Obsoletes:      python3-googleapis-common-protos < %{version}
%endif
%python_subpackages

%description
googleapis-common-protos contains the python classes generated from the common
protos in the googleapis_ repository.

%prep
%autosetup -p1 -n %{modname}-%{version}

install -p -D -t tests/unit %{SOURCE1}

%build
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
%pytest

%files %{python_files}
%license LICENSE
%doc README.rst
%dir %{python_sitelib}/google
%{python_sitelib}/google/type
%{python_sitelib}/google/longrunning
%{python_sitelib}/google/rpc
%{python_sitelib}/google/logging
%{python_sitelib}/google/api
%{python_sitelib}/google/gapic
%{python_sitelib}/google/cloud
%{python_sitelib}/%{pkgname}-%{version}*-info

%changelog
* Thu Jul  4 2024 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to 1.63.2
  * **deps:** Require protobuf >= 3.20.2 (c77c0dc)
  * Regenerate pb2 files for compatibility with protobuf 5.x (c77c0dc)
* Mon Jun 24 2024 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to 1.63.1
  * Increase upper limit for protobuf 5.X versions (#212)
* Sun Apr  7 2024 Dirk Müller <dmueller@suse.com>
- update to 1.63.0:
  * Add `api_version` field to `ServiceOptions` in
    `google/api/client.proto`
  * Add `LOCATION_POLICY_VIOLATED` enum to `ErrorReason` in
    `google/api/error_reason.proto`
  * Add `rest_reference_documentation_uri` field to
    `ServiceOptions` in `google/api/client.proto`
* Tue Mar  5 2024 Robert Schweikert <rjschwei@suse.com>
- Obsolete Python 3.6 build for SLE 15 SP4 and openSUSE Leap 15.4 and later
* Mon Feb 26 2024 Robert Schweikert <rjschwei@suse.com>
- Version update in SLE 15 SP4 and later (jsc#PED-6697)
* Sat Dec 16 2023 Dirk Müller <dmueller@suse.com>
- update to 1.62.0:
  * Add `auto_populated_fields` field of `MethodSettings` in
    `google/api/client_pb2` (#194)
  * Add support for Python 3.12 (#192)
  * Migrate to native namespace packages (#187)
* Wed Dec  6 2023 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to 1.61.0
  * Add `google/api/field_info.proto` (2d39f37)
  * Add `IDENTIFIER` to `FieldBehavior` enum (2d39f37)
* Thu Aug 17 2023 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to 1.60.0
  * Add `google/api/policy.proto` (b2cb5c2)
  * Add `method_policies` to `Control` (b2cb5c2)
* Sun Jul  2 2023 ecsos <ecsos@opensuse.org>
- Add %%{?sle15_python_module_pythons}
* Tue Jun 20 2023 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to 1.59.1
  * Invalid `dev` version identifiers in `setup.py` (#166), closes (#165)
* Wed Apr  5 2023 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to 1.59.0
  * Add overrides_by_request_protocol to BackendRule
    in google/api/backend.proto (77376dd)
  * Add proto_reference_documentation_uri to Publishing
    in google/api/client.proto (77376dd)
  * Add SERVICE_NOT_VISIBLE and GCP_SUSPENDED to ErrorReason
    in google/api/error_reason.proto (77376dd)
  * Use rst syntax in readme (77376dd)
* Thu Mar  2 2023 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to 1.58.0
  * Add google/rpc/context/audit_context.proto (41f1529)
  * Add google/rpc/http.proto (41f1529)
* Thu Jan  5 2023 Dirk Müller <dmueller@suse.com>
- update to v1.57.1:
  * Mark reference_docs_uri field in google/api/client.proto as deprecated
* Thu Dec  1 2022 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to 1.57.0:
  * Add support for Python 3.10 (#143)
  * Add support for Python 3.11 (#145)
  * Added google.api.JwtLocation.cookie (6af2132)
  * Added google.api.Service.publishing and client libraries settings (6af2132)
  * New fields in enum google.api.ErrorReason (6af2132)
  * Deprecate google.api.BackendRule.min_deadline (6af2132)
  * **deps:** Require protobuf >=3.19.5 (#141)
  * Minor updates to comments (6af2132)
- Update BuildRequires and Requires from setup.py
* Thu Sep  8 2022 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to 1.56.4:
  * require python 3.7+ (#119)
- from version 1.56.3:
  * **deps:** allow protobuf < 5.0.0 (#112)
  * fix changelog header to consistent size (#108)
- from version 1.56.2:
  * **deps:** require grpcio >= 1.0.0, <2.0.0dev (4a402ce)
  * **deps:** require protobuf>= 3.15.0, <4.0.0dev (#105)
- from version 1.56.1:
  * **deps:** require protobuf >=1.15.0 (f04ed64)
  * include tests directory (#103)
  * regenerate pb2 files using the latest version of grpcio-tools (f04ed64)
- Rename README.md to README.rst in %%doc section
- Update BuildRequires and Requires from setup.py
* Mon Apr 25 2022 Matej Cepl <mcepl@suse.com>
- Upgrade to 1.56.0:
  - add google/api/error_reason.proto (62c04b8)
  - add google/api/visibility.proto (62c04b8)
  - add google/type/decimal.proto (62c04b8)
  - add google/type/interval.proto (62c04b8)
  - add google/type/localized_text.proto (62c04b8)
  - add google/type/phone_number.proto (62c04b8)
  - update all protos and pb2 files (62c04b8)
  - expose all names in longrunning _pb2's (#90) (09e9ccd)
  - re-generate pb2 files (#87) (6260547)
  - re-generate pb2 files using grpcio-tools<1.44.0 (#93) (76bb9f6)
  - remove deprecated fields aliases and features from google/api/endpoint.proto (62c04b8)
- Upgrade to 1.55.0:
  - add location proto files. (#84) (9a33e56)
- Upgrade to 1.54.0:
  - add extended_operations.proto (#77) (bc85849)
  - add google/api/routing.proto (#75) (1ae0bbc)
- Upgrade to 1.53.0:
  - add google.api.ResourceDescriptor.Style (4ce679c)
  - add API method signatures to longrunning operations (8de7ae2)
  - add gapic_metadata_pb2 (#38) (8de7ae2)
  - add UNORDERED_LIST to field options (8de7ae2)
  - add WaitOperation method to longrunning operations (8de7ae2)
  - add google.api.ResourceDescriptor.Style (4ce679c)
  - require python >=3.6 and (#31) (4ce679c)
  - add create_key to FieldDescriptors (4ce679c)
  - Generate gRPC files for long-running operations (#13) (a9ce288)
  - add link to PyPI (#10) (3f79402)
  - add create_key to FieldDescriptors (4ce679c)
  - Generate gRPC files for long-running operations (#13) (a9ce288)
  - add link to PyPI (#10) (3f79402)
* Wed Sep 23 2020 Dirk Mueller <dmueller@suse.com>
- update to 1.52.0
  * create api-common-protos repo for python common protos
* Wed Apr  8 2020 Marketa Calabkova <mcalabkova@suse.com>
- Update to 1.51.0
  * Adding RetryPolicy to pubsub.proto
  * API definition for (not-yet-launched) GCS gRPC.
  * And many many more (the commit log is just too long to read)
* Mon Aug 12 2019 Marketa Calabkova <mcalabkova@suse.com>
- Update to 1.6.0
  * no upstream changelog
* Tue Mar 26 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 1.5.9:
  * no upstream changelog
* Fri Mar 15 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 1.5.8:
  * no upstream changelog
* Tue Dec  4 2018 Matej Cepl <mcepl@suse.com>
- Remove superfluous devel dependency for noarch package
* Fri May 18 2018 tbechtold@suse.com
- Initial packaging (version 1.5.3)
